@@ -5,7 +5,8 @@ from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
-from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
+from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
+    Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
 from tkdev.devcore import DevAction, DevSysTray
 from tkdev.devdraw import DrawButton
@@ -48,6 +49,62 @@ Dark = "dark"
 DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
+def AddShortCut(File, Link="link.lnk", Path: str = ".//"):
+    from win32com.client import Dispatch
+    from shutil import move
+    Shell = Dispatch("WScript.Shell")
+    ShortCut = Shell.CreateShortCut(Link)
+    ShortCut.TargetPath = File
+    ShortCut.save()
+    move(Link, Path)
+
+
+def AddStartMenu(File: str):
+    from getpass import getuser
+    from shutil import move
+    move(File, f"C:\\Users\\{getuser()}\\AppData\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs")
+
+
+def AutoStart(File: str, Name: str = "Application"):
+    try:
+        Key = RegOpenKey(HKEY_CURRENT_USER, "Software\\Microsoft\\Windows\\CurrentVersion\\Run", 0, KEY_ALL_ACCESS)
+        RegSetValueEx(Key, Name, 0, REG_SZ, File)
+        RegCloseKey(Key)
+    except:
+        print('Add Error')
+
+
+def Package(File, Ofter="-w", StartMenu: bool = True):
+    try:
+        import pyinstaller
+    except:
+        Install("pyinstaller")
+    import sys
+    import os
+    import os.path
+
+    os.system(os.path.split(sys.executable)[0]+f"\\Scripts\\pyinstaller.exe {Ofter} {File}")
+
+    if StartMenu:
+        from getpass import getuser
+        print("asdas")
+        name = os.path.splitext(os.path.split(File)[1])[0]
+        print(name)
+        if os.path.exists("dist\\"+name+".exe"):
+            path = "dist\\"+name+".exe"
+        elif os.path.exists("dist\\"+name+"\\"+name+".exe"):
+            path = "dist\\"+name+"\\"+name+".exe"
+        print(path)
+        print(os.getcwd())
+        from win32com.client import Dispatch
+        from shutil import move
+        Shell = Dispatch("WScript.Shell")
+        ShortCut = Shell.CreateShortCut(name+".lnk")
+        ShortCut.TargetPath = os.getcwd()+path
+        ShortCut.save()
+        move(name+".lnk", f"C:\\Users\\{getuser()}\\AppData\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs")
+
+
 def UpGrade(Library, Basic: bool = True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     import os
     import sys
@@ -59,6 +116,7 @@ def UpGrade(Library, Basic: bool = True, Preview: bool = False, Pypi="https://py
     print(f"{sys.executable} -m pip install {Library} {Librarys} {Pre} --upgrade")
     os.system(f"{sys.executable} -m pip install {Library} {Librarys} {Pre} --upgrade")
 
+
 def Install(Library, Basic: bool = True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     import os
     import sys
@@ -352,6 +410,7 @@ def window_border(window: tk.Tk):
         SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
         SetWindowPos(hWnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
         UpdateWindow(hWnd)
+
     window.after(100, border)
 
 
@@ -978,7 +1037,8 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 
 class DevTooltip(DevToplevel):
-    def __init__(self, widget: tk.Widget, window: tk.Tk, message: str = "", after: int = 1000, border: bool = True, padding: int = 3, side=tk.CENTER, height: int = 40,
+    def __init__(self, widget: tk.Widget, window: tk.Tk, message: str = "", after: int = 1000, border: bool = True,
+                 padding: int = 3, side=tk.CENTER, height: int = 40,
                  background="#ffffff", foreground="#000000"):
         super(DevTooltip, self).__init__()
         self.configure(background=background, relief=tk.RAISED, border=1)
@@ -1046,6 +1106,4 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    Window = DevWindow()
-    DevTooltip(Window, Window, message="我是一个工具提示", after=0)
-    Window.mainloop()
\ No newline at end of file
+    Package("C:\\tkinterDev\\demo-4.py", Ofter="-F -w")
